==> libgtk-java-2.7.0.tar.bz2: libgtk-java-2.7.0/src/java/org/gnu/gtk/VBox.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

import org.gnu.glib.Type;
import org.gnu.javagnome.Handle;

/**
 * VBox is a container widget that organizes its contained widgets
 * vertically. Most manipulation methods are part of the super class, Box
 * @see Box
 * @see HBox
 */
public class VBox extends Box {
	/**
	 * Constructs a new VBox widget
	 * @param homogenous TRUE if all children are to be given equal space allotments.
	 * @param spacing The  number of pixels to place by default between children.
	 */
	public VBox (boolean homogenous, int spacing) {
		super(gtk_vbox_new (homogenous, spacing));
	}
	
	/**
	 * Construct a VBox widget from a handle to a native resource.
	 */
	public VBox(Handle handle) {
	    super(handle);
	}
    
    /**
     * Construct a VBox widget from a handle to a native resource.
     */
    public static VBox getVBox(Handle handle) {
        if (handle == null)
            return null;
        
        VBox obj = (VBox) getGObjectFromHandle(handle);
        if (obj == null)
            obj = new VBox(handle);
        
        return obj;
    }
	
	/**
	 * Retrieve the runtime type used by the GLib library.
	 */
	public static Type getType() {
		return new Type(gtk_vbox_get_type());
	}

    native static final protected int gtk_vbox_get_type ();
    native static final protected Handle gtk_vbox_new (boolean homogenous, int spacing);
}

==> libgtk-java-2.8.1.tar.bz2: libgtk-java-2.8.1/src/java/org/gnu/gtk/VBox.java <==
/*
 * Java-Gnome Bindings Library
 *
 * Copyright 1998-2004 the Java-Gnome Team, all rights reserved.
 *
 * The Java-Gnome bindings library is free software distributed under
 * the terms of the GNU Library General Public License version 2.
 */

package org.gnu.gtk;

import org.gnu.glib.Type;
import org.gnu.glib.Handle;

/**
 * VBox is a container widget that organizes its contained widgets
 * vertically. Most manipulation methods are part of the super class, Box
 * @see Box
 * @see HBox
 */
public class VBox extends Box {
	/**
	 * Constructs a new VBox widget
	 * @param homogenous TRUE if all children are to be given equal space allotments.
	 * @param spacing The  number of pixels to place by default between children.
	 */
	public VBox (boolean homogenous, int spacing) {
		super(gtk_vbox_new (homogenous, spacing));
	}
	
	/**
	 * Construct a VBox widget from a handle to a native resource.
	 */
	public VBox(Handle handle) {
	    super(handle);
	}
    
    /**
     * Construct a VBox widget from a handle to a native resource.
     */
    public static VBox getVBox(Handle handle) {
        if (handle == null)
            return null;
        
        VBox obj = (VBox) getGObjectFromHandle(handle);
        if (obj == null)
            obj = new VBox(handle);
        
        return obj;
    }
	
	/**
	 * Retrieve the runtime type used by the GLib library.
	 */
	public static Type getType() {
		return new Type(gtk_vbox_get_type());
	}

    native static final protected int gtk_vbox_get_type ();
    native static final protected Handle gtk_vbox_new (boolean homogenous, int spacing);
}
